@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-27'; # DATE
+our $DATE = '2022-10-15'; # DATE
 our $DIST = 'App-tabledata'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our %SPEC;
 
@@ -219,7 +219,7 @@ App::tabledata - Show content of TableData modules (plus a few other things)
 
 =head1 VERSION
 
-This document describes version 0.003 of App::tabledata (from Perl distribution App-tabledata), released on 2022-07-27.
+This document describes version 0.004 of App::tabledata (from Perl distribution App-tabledata), released on 2022-10-15.
 
 =head1 SYNOPSIS
 
@@ -244,10 +244,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<action> => I<str> (default: "dump_as_aoaos")
 
+(No description)
+
 =item * B<detail> => I<bool>
 
+(No description)
+
 =item * B<module> => I<perl::tabledata::modname_with_optional_args>
 
+(No description)
+
 =item * B<num> => I<posint> (default: 1)
 
 Number of rows to get (e.g. for pick_rows or head action).
@@ -297,9 +303,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
